/* COBRA manager parsing library.
 * This software is released into the public domain.
 */

#include "manager.h"
#include <stdio.h>
#include <stdlib.h>
#include <dirent.h>
#include <string.h>

static void
set_name (char *out, char *name)
{
  strcpy (out, COBRA_PATH);
  strcat (out, "/");
  strcat (out, name);
}

int manager_parse (Manager *manager)
{
  DIR *d;
  struct dirent *e;
  int i;

  memset (manager, 0, sizeof(Manager));

  d = opendir(COBRA_PATH);
  if (!d)
  {
    return -1;
  }

  // Find disc.iso and game ids
  while((e = readdir(d)) != NULL)
  {
    if(e->d_type != DT_REG)
      continue;

    if (strcmp (e->d_name, "DISC.ISO") == 0)
      set_name (manager->disc_iso, e->d_name);
    else if (strlen (e->d_name) == 9)
    {
      if (manager->num_iso < MAX_ISO)
      {
        strcpy (manager->iso[manager->num_iso].game_id, e->d_name);
        set_name (manager->iso[manager->num_iso].info, e->d_name);
        manager->num_iso++;
      }
    }
  }

  // rewinddir does not work on the ps3, so we reopen the dir
  // rewinddir (d);

  // now go look for the sfo/png/run of each game found
  closedir(d);
  d = opendir(COBRA_PATH);
  if (!d)
  {
    memset (manager, 0, sizeof(Manager));
    return -1;
  }

  while((e = readdir(d)) != NULL)
  {
    if(e->d_type != DT_REG)
      continue;

    for (i = 0; i < manager->num_iso; i++)
    {
      if (strlen (e->d_name) > 9 &&
          memcmp (e->d_name, manager->iso[i].game_id, 9) == 0)
      {
        if (strcmp (e->d_name + 9, ".PNG") == 0)
          set_name (manager->iso[i].png, e->d_name);
        else if (strcmp (e->d_name + 9, ".SFO") == 0)
          set_name (manager->iso[i].sfo, e->d_name);
        else if (strcmp (e->d_name + 9, ".RUN") == 0)
          set_name (manager->iso[i].run, e->d_name);
        break;
      }
    }
  }
  closedir(d);

  for (i = 0; i < manager->num_iso; i++)
  {
    if (manager->iso[i].sfo[0] == 0 ||
        manager->iso[i].png[0] == 0 ||
        manager->iso[i].run[0] == 0)
    {
      // Remove iso files with missing png/sfo/run
      memmove (&manager->iso[i], &manager->iso[i+1], sizeof(Iso) * (manager->num_iso-i-1));
      manager->num_iso--;
      i--;
    }
  }

  return manager->num_iso;
}
