/* COBRA manager parsing library.
 * This software is released into the public domain.
 */
#ifndef _MANAGER_H_
#define _MANAGER_H_

/*
 * This library provides a single API to parse the available ISO files
 * provided by the COBRA ODE.
 * You can communicate with the COBRA ODE firmware by accessing those
 * files. Please refer to user manual for more information.
 *
 * You must allocate a Manager structure and call manager_parse to get
 * a list of all valid ISO files. It will fill the structure and return
 * the number of games found.
 * example of use :
 *
  Manager manager;
  int i;

  manager_parse(&manager);

  // Parse all ISO files
  for (i = 0; i < manager.num_iso; i++)
  {
    char iso_filename[2048];
    FILE *info = fopen (manager.iso[i].info, "rb");

    fread (iso_filename, 1, 2048, info);
    fclose (info);

    load_png_from_file(manager.iso[i].png);
    parse_sfo_file(manager.iso[i].sfo);
  }

  // User selected game
  FILE *run = fopen (manager.iso[selection].run, "rb");
  fread (buffer, 1, 2048, run);
  fclose (run);

  // User dumps disc
  FILE *disc = fopen (manager.disc_iso, "rb");
  FILE *out = fopen("/dev_usb000/game.iso", "wb");

  while (1)
  {
    int bytes = fread (buffer, 1, 2048, disc);
    fwrite (buffer, 1, bytes, out);
    // Update progress
    if (bytes != 2048)
      break;
  }
  fclose (disc);
  fclose (out);

 *
 */

#define MAX_ISO 128
#define MAX_FILENAME_LENGTH 128
#define DEV_BDVD "/dev_bdvd"
#define COBRA_PATH DEV_BDVD "/COBRA"

typedef struct {
  char game_id[10];
  char info[MAX_FILENAME_LENGTH+1];
  char png[MAX_FILENAME_LENGTH+1];
  char sfo[MAX_FILENAME_LENGTH+1];
  char run[MAX_FILENAME_LENGTH+1];
} Iso;

typedef struct {
  Iso iso[MAX_ISO];
  int num_iso;
  char disc_iso[MAX_FILENAME_LENGTH+1];
} Manager;

int manager_parse (Manager *manager);

#endif
